@@ -75,6 +75,7 @@ gtk_source_hover_assistant_should_dismiss (GtkSourceHoverAssistant *self)
 		GdkRectangle popup_area, root_area;
 		double popup_x, popup_y;
 		double transform_x, transform_y;
+		GtkWidget *view;
 		GtkRoot *root;
 
 		popup_x = gdk_popup_get_position_x (GDK_POPUP (surface));
@@ -97,6 +98,34 @@ gtk_source_hover_assistant_should_dismiss (GtkSourceHoverAssistant *self)
 		{
 			return FALSE;
 		}
+
+		/* If our cursor is still within the hovered_at area we
+		 * do not want to dismiss yet either.
+		 */
+		if ((view = gtk_widget_get_ancestor (GTK_WIDGET (self), GTK_SOURCE_TYPE_VIEW)))
+		{
+			graphene_point_t point;
+			int buffer_x;
+			int buffer_y;
+
+			if (gtk_widget_compute_point (GTK_WIDGET (root),
+			                              view,
+			                              &GRAPHENE_POINT_INIT (self->root_x, self->root_y),
+			                              &point))
+			{
+				gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (view),
+				                                       GTK_TEXT_WINDOW_WIDGET,
+				                                       point.x,
+				                                       point.y,
+				                                       &buffer_x,
+				                                       &buffer_y);
+
+				if (gdk_rectangle_contains_point (&self->hovered_at, buffer_x, buffer_y))
+				{
+					return FALSE;
+				}
+			}
+		}
 	}
 
 	return TRUE;
@@ -314,6 +343,32 @@ gtk_source_hover_assistant_dispose (GObject *object)
 	G_OBJECT_CLASS (gtk_source_hover_assistant_parent_class)->dispose (object);
 }
 
+static void
+gtk_source_hover_assistant_click_pressed_cb (GtkSourceHoverAssistant *self,
+                                             int                      n_press,
+                                             double                   x,
+                                             double                   y,
+                                             GtkGestureClick         *click)
+{
+	GdkEventSequence *sequence;
+	GdkEvent *event;
+
+	g_assert (GTK_SOURCE_IS_HOVER_ASSISTANT (self));
+	g_assert (GTK_IS_GESTURE_CLICK (click));
+
+	sequence = gtk_gesture_single_get_current_sequence (GTK_GESTURE_SINGLE (click));
+	event = gtk_gesture_get_last_event (GTK_GESTURE (click), sequence);
+
+	/* WORKAROUND: See comment below in gtk_source_hover_assistant_init().
+	 * We have to block context menus from here until we can be sure they'll
+	 * work with GtkPopover:autohide disabled.
+	 */
+	if (gdk_event_triggers_context_menu (event))
+	{
+		gtk_gesture_set_state (GTK_GESTURE (click), GTK_EVENT_SEQUENCE_CLAIMED);
+	}
+}
+
 static void
 gtk_source_hover_assistant_class_init (GtkSourceHoverAssistantClass *klass)
 {
@@ -334,6 +389,7 @@ gtk_source_hover_assistant_class_init (GtkSourceHoverAssistantClass *klass)
 static void
 gtk_source_hover_assistant_init (GtkSourceHoverAssistant *self)
 {
+	GtkEventController *click;
 	GtkEventController *scroll;
 
 	gtk_widget_add_css_class (GTK_WIDGET (self), "hover-assistant");
@@ -360,6 +416,21 @@ gtk_source_hover_assistant_init (GtkSourceHoverAssistant *self)
 	                         self,
 	                         G_CONNECT_SWAPPED);
 	gtk_widget_add_controller (GTK_WIDGET (self), g_object_ref (self->popover_motion));
+
+	/* WORKAROUND: Until we have a way to ensure that showing context
+	 * menus from the popover won't break our popover, we need to prevent
+	 * them from potentially breaking input/grabs.
+	 */
+	click = GTK_EVENT_CONTROLLER (gtk_gesture_click_new ());
+	g_signal_connect_object (click,
+	                         "pressed",
+	                         G_CALLBACK (gtk_source_hover_assistant_click_pressed_cb),
+	                         self,
+	                         G_CONNECT_SWAPPED);
+	gtk_gesture_single_set_button (GTK_GESTURE_SINGLE (click), 0);
+	gtk_gesture_single_set_exclusive (GTK_GESTURE_SINGLE (click), TRUE);
+	gtk_event_controller_set_propagation_phase (GTK_EVENT_CONTROLLER (click), GTK_PHASE_CAPTURE);
+	gtk_widget_add_controller (GTK_WIDGET (self), GTK_EVENT_CONTROLLER (click));
 }
 
 GtkSourceAssistant *
@@ -385,8 +456,11 @@ gtk_source_hover_assistant_populate_cb (GObject      *object,
 	{
 		if (!self->disposed)
 		{
-			gtk_widget_set_visible (GTK_WIDGET (self),
-			                        !_gtk_source_hover_display_is_empty (self->display));
+			GtkWidget *parent = gtk_widget_get_parent (GTK_WIDGET (self));
+			gboolean mapped = parent && gtk_widget_get_mapped (parent);
+			gboolean empty = _gtk_source_hover_display_is_empty (self->display);
+
+			gtk_widget_set_visible (GTK_WIDGET (self), mapped && !empty);
 		}
 	}
 
